sipua
=====

.. image:: https://img.shields.io/pypi/l/sipua.svg
   :target: https://pypi.python.org/pypi/sipua
   :alt: License

.. image:: https://img.shields.io/pypi/v/sipua.svg
   :target: https://pypi.python.org/pypi/sipua
   :alt: Version

.. image:: https://github.com/spacinov/sipua/workflows/tests/badge.svg
   :target: https://github.com/spacinov/sipua/actions
   :alt: Tests

.. image:: https://img.shields.io/codecov/c/github/spacinov/sipua.svg
   :target: https://codecov.io/gh/spacinov/sipua
   :alt: Coverage

The ``sipua`` project provides a library for writing SIP user agents in Python.

API Reference
-------------

.. toctree::
   :maxdepth: 2

   transaction
   transport
   utils
